# Generated by Django 2.0.5 on 2018-06-01 03:53

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name='UrlMap',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('full_url', models.CharField(max_length=256)),
                ('short_url', models.CharField(db_index=True, max_length=50, unique=True)),
                ('usage_count', models.IntegerField(default=0)),
                ('max_count', models.IntegerField(default=-1)),
                ('lifespan', models.IntegerField(default=-1)),
                ('date_created', models.DateTimeField(auto_now_add=True)),
                ('date_expired', models.DateTimeField()),
                ('user', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL)),
            ],
        ),
        migrations.CreateModel(
            name='UrlProfile',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('enabled', models.BooleanField(default=True)),
                ('max_urls', models.IntegerField(default=-1)),
                ('max_concurrent_urls', models.IntegerField(default=100)),
                ('default_lifespan', models.IntegerField(default=120)),
                ('default_max_uses', models.IntegerField(default=-1)),
                ('user', models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL)),
            ],
        ),
    ]
